@@ -1283,8 +1283,8 @@ static void parseTextIntoCellsLinesRuns (Graphics me, conststring32 txt /* catta
 	bool globalCode = false, globalLink = false, verbatimLink = false;
 	bool globalSmall = 0;
 	numberOfLinks = 0;
-	const bool weAreInManual = ( my dollarSignIsCode );
-	const bool weAreInNotebook = ( my backquoteIsVerbatim );
+	const bool weAreInManual = ( my dollarSignIsCode );   // TODO: this is temporary
+	const bool weAreInNotebook = ( my backquoteIsVerbatim );   // TODO: this is temporary
 	const bool topDownVerbatim = ( my font == kGraphics_font::COURIER && weAreInNotebook );
 	bool globalVerbatim = topDownVerbatim;
 	bool thinLink = false;
@@ -1329,13 +1329,13 @@ static void parseTextIntoCellsLinesRuns (Graphics me, conststring32 txt /* catta
 				in ++;
 				wordItalic = wordBold = wordCode = false;
 				continue;
-			} else if (! weAreInManual) {
+			} else if (! weAreInManual) {   // TODO: this is temporary
 				static integer countCharacterSubscript;
 				trace (U"Character subscript: ", ++ countCharacterSubscript, U" ", txt);
 				charSubscript = true;
 				wordItalic = wordBold = wordCode = false;
 				continue;
-			} else if (weAreInNotebook) {
+			} else if (weAreInNotebook) {   // TODO: this is temporary
 				charSubscript = true;
 				wordItalic = wordBold = wordCode = false;
 				continue;
@@ -1369,7 +1369,7 @@ static void parseTextIntoCellsLinesRuns (Graphics me, conststring32 txt /* catta
 				else
 					wordItalic = true;
 				continue;
-			} else if (weAreInNotebook) {
+			} else if (weAreInNotebook) {   // TODO: this is temporary
 				charItalic = true;
 				continue;
 			} else {
@@ -2143,7 +2143,7 @@ double Graphics_textWidth_ps (Graphics me, conststring32 txt, bool useSilipaPS)
 			int numberOfFamilies;
 			pango_font_map_list_families (thePangoFontMap, & families, & numberOfFamilies);
 			for (int i = 0; i < numberOfFamilies; i ++)
-				fprintf (stderr, "%d %s\n", i, pango_font_family_get_name (families [i]));
+				fprintf (Melder_stderr, "%d %s\n", i, pango_font_family_get_name (families [i]));
 			g_free (families);
 		#endif
 		const char *trueName;
@@ -2163,8 +2163,8 @@ double Graphics_textWidth_ps (Graphics me, conststring32 txt, bool useSilipaPS)
 		testFont ("Symbol");
 		testFont ("Dingbats");
 		#if 0   /* For debugging: list font availability. */
-			fprintf (stderr, "times %d helvetica %d courier %d palatino %d doulos %d charis %d\n",
-				hasTimes, hasHelvetica, hasCourier, hasPalatino, hasDoulos, hasCharis);
+			fprintf (Melder_stderr, "times %d helvetica %d courier %d palatino %d doulos %d charis %d\n",
+					hasTimes, hasHelvetica, hasCourier, hasPalatino, hasDoulos, hasCharis);
 		#endif
 		inited = true;
 		return true;
